==> nextcloud-app-mail-1.1.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/nb.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "E-post",
    "Auto detect failed. Please use manual mode." : "Automatisk påvisning mislyktes. Bruk manuelt oppsett.",
    "Updating account failed: " : "Oppdatering av konto mislyktes:",
    "Creating account failed: " : "Oppretting av konto mislyktes:",
    "Auto" : "Auto",
    "Name" : "Navn",
    "Mail Address" : "E-postadresse",
    "Password" : "Passord",
    "Manual" : "Manuell",
    "IMAP Settings" : "IMAP-innstillinger",
    "IMAP Host" : "IMAP-server",
    "IMAP Security" : "IMAP-sikkerhet",
    "None" : "Ingen",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP-port",
    "IMAP User" : "IMAP-bruker",
    "IMAP Password" : "IMAP-passord",
    "SMTP Settings" : "SMTP-innstillinger",
    "SMTP Host" : "SMTP-server",
    "SMTP Security" : "SMTP-sikkerhet",
    "SMTP Port" : "SMTP-port",
    "SMTP User" : "SMTP-bruker",
    "SMTP Password" : "SMTP-passord",
    "Save" : "Lagre",
    "Connect" : "Koble til",
    "Add mail account" : "Legg til e-postkonto",
    "Use Gravatar and favicon avatars" : "Bruk Gravatar- og favikon-avatarer",
    "Keyboard shortcuts" : "Tastatursnarveier",
    "Select account" : "Velg konto",
    "Subject" : "Emne",
    "Saving draft …" : "Lagrer kladd…",
    "Draft saved" : "Kladd ble lagret",
    "Upload attachment" : "Last opp vedlegg",
    "Add attachment from Files" : "Legg til vedlegg fra Filer",
    "Uploading attachments …" : "Laster opp vedlegg…",
    "Sending …" : "Sender…",
    "Error sending your message" : "Feil ved sending av meldingen din",
    "Go back" : "Gå tilbake",
    "Retry" : "Prøv igjen",
    "Message sent!" : "Melding sendt!",
    "Reply sent!" : "Svar sendt!",
    "Write another message" : "Skriv en ny melding",
    "Send" : "Send",
    "Choose a file to add as attachment" : "Velg en fil å legge til som vedlegg",
    "No messages in this folder" : "Ingen meldinger i denne mappen",
    "Draft: " : "Kladd:",
    "Mark read" : "Marker som lest",
    "Mark unread" : "Marker som ulest",
    "Delete" : "Slett",
    "Report this bug" : "Rapporter denne feilen",
    "Loading messages" : "Henter meldinger",
    "Not found" : "Ikke funnet",
    "Reply" : "Svar",
    "Forward" : "Fremover",
    "Could not load your message" : "Kunne ikke laste meldingene dine",
    "Import into calendar" : "Importer til kalender",
    "Download attachment" : "Last ned vedlegg",
    "Save to Files" : "Lagre i Filer",
    "Choose a folder to store the attachment in" : "Velg en mappe å lagre vedlegget i",
    "Save all to Files" : "Lagre alle i Filer",
    "Choose a folder to store the attachments in" : "Velg en mappe å lagre vedleggene i",
    "The images have been blocked to protect your privacy." : "Bildene har blitt blokkert for å beskytte privatlivet.",
    "Show images from this\tsender" : "Vis bilder fra denne avsenderen",
    "New message" : "Ny melding",
    "Settings" : "Innstillinger",
    "Add folder" : "Legg til mappe",
    "Delete account" : "Slett konto",
    "Show all folders" : "Vis alle mapper",
    "Collapse folders" : "Skjul mapper",
    "Mark all as read" : "Marker alle som lest",
    "Loading …" : "Laster...",
    "Could not load your draft" : "Kunne ikke laste inn denne kladden",
    "Signature" : "Signatur",
    "General" : "Generell",
    "User" : "Bruker",
    "Host" : "Server",
    "Port" : "Port",
    "Speed up your Mail experience with these quick shortcuts." : "Arbeid raskere i Mail med disse raske snarveiene",
    "Compose new message" : "Lag ny melding",
    "Newer message" : "Nyere melding",
    "Older message" : "Eldre melding",
    "Toggle star" : "Merk med stjerne",
    "Toggle unread" : "Merk som ulest",
    "Search" : "Søk",
    "Refresh" : "Oppdater",
    "Connect your mail account" : "Koble til din e-postkonto",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n ny melding \nfra {from}","%n nye meldinger \nfra {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "Could not load {tag}{name}{endtag}" : "Kunne ikke laste {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Det oppstod et problem under lasting av {tag}{name}{endtag}",
    "Could not load the desired message" : "Kunne ikke laste den ønskede meldingen",
    "Could not load the message" : "Kunne ikke laste meldingen",
    "Error loading message" : "Feil ved innlasting av melding",
    "Forwarding to %s" : "Videresender til %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klikk her hvis du ikke blir videresendt automatisk innen noen få sekunder.",
    "Redirect" : "Videresend",
    "The link leads to %s" : "Denne lenken leder til %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Hvis du ikke ønsker å besøke den siden, kan du returnere til <a href=\"%s\">E-post</a>.",
    "Continue to %s" : "Fortsett til %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-1.3.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/nb.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "E-post",
    "Auto detect failed. Please use manual mode." : "Automatisk påvisning mislyktes. Bruk manuelt oppsett.",
    "Updating account failed: " : "Oppdatering av konto mislyktes:",
    "Creating account failed: " : "Oppretting av konto mislyktes:",
    "Auto" : "Auto",
    "Name" : "Navn",
    "Mail Address" : "E-postadresse",
    "Password" : "Passord",
    "Manual" : "Manuell",
    "IMAP Settings" : "IMAP-innstillinger",
    "IMAP Host" : "IMAP-server",
    "IMAP Security" : "IMAP-sikkerhet",
    "None" : "Ingen",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP-port",
    "IMAP User" : "IMAP-bruker",
    "IMAP Password" : "IMAP-passord",
    "SMTP Settings" : "SMTP-innstillinger",
    "SMTP Host" : "SMTP-server",
    "SMTP Security" : "SMTP-sikkerhet",
    "SMTP Port" : "SMTP-port",
    "SMTP User" : "SMTP-bruker",
    "SMTP Password" : "SMTP-passord",
    "Save" : "Lagre",
    "Connect" : "Koble til",
    "Add mail account" : "Legg til e-postkonto",
    "Use Gravatar and favicon avatars" : "Bruk Gravatar- og favikon-avatarer",
    "Keyboard shortcuts" : "Tastatursnarveier",
    "Select account" : "Velg konto",
    "Subject" : "Emne",
    "Saving draft …" : "Lagrer kladd…",
    "Draft saved" : "Kladd ble lagret",
    "Upload attachment" : "Last opp vedlegg",
    "Add attachment from Files" : "Legg til vedlegg fra Filer",
    "Uploading attachments …" : "Laster opp vedlegg…",
    "Sending …" : "Sender…",
    "Error sending your message" : "Feil ved sending av meldingen din",
    "Go back" : "Gå tilbake",
    "Retry" : "Prøv igjen",
    "Message sent!" : "Melding sendt!",
    "Write another message" : "Skriv en ny melding",
    "Send" : "Send",
    "Choose a file to add as attachment" : "Velg en fil å legge til som vedlegg",
    "No messages in this folder" : "Ingen meldinger i denne mappen",
    "Draft: " : "Kladd:",
    "Unfavorite" : "Fjern favorittmarkering",
    "Favorite" : "Merk som favoritt",
    "Mark read" : "Marker som lest",
    "Mark unread" : "Marker som ulest",
    "Delete" : "Slett",
    "Report this bug" : "Rapporter denne feilen",
    "Loading messages" : "Henter meldinger",
    "Not found" : "Ikke funnet",
    "to" : "til",
    "cc" : "cc",
    "Reply" : "Svar",
    "Forward" : "Fremover",
    "Could not load your message" : "Kunne ikke laste meldingene dine",
    "Import into calendar" : "Importer til kalender",
    "Download attachment" : "Last ned vedlegg",
    "Save to Files" : "Lagre i Filer",
    "Unnamed" : "Uten navn",
    "Choose a folder to store the attachment in" : "Velg en mappe å lagre vedlegget i",
    "Save all to Files" : "Lagre alle i Filer",
    "Choose a folder to store the attachments in" : "Velg en mappe å lagre vedleggene i",
    "The images have been blocked to protect your privacy." : "Bildene har blitt blokkert for å beskytte privatlivet.",
    "Show images from this\tsender" : "Vis bilder fra denne avsenderen",
    "New message" : "Ny melding",
    "Settings" : "Innstillinger",
    "Add folder" : "Legg til mappe",
    "Delete account" : "Slett konto",
    "Show all folders" : "Vis alle mapper",
    "Collapse folders" : "Skjul mapper",
    "Mark all as read" : "Marker alle som lest",
    "Loading …" : "Laster...",
    "Could not load your draft" : "Kunne ikke laste inn denne kladden",
    "Signature" : "Signatur",
    "General" : "Generell",
    "User" : "Bruker",
    "Host" : "Server",
    "Port" : "Port",
    "Speed up your Mail experience with these quick shortcuts." : "Arbeid raskere i Mail med disse raske snarveiene",
    "Compose new message" : "Lag ny melding",
    "Newer message" : "Nyere melding",
    "Older message" : "Eldre melding",
    "Toggle star" : "Merk med stjerne",
    "Toggle unread" : "Merk som ulest",
    "Search" : "Søk",
    "Refresh" : "Oppdater",
    "Connect your mail account" : "Koble til din e-postkonto",
    "All" : "Alle",
    "Archive" : "Arkiv",
    "Drafts" : "Kladder",
    "Favorites" : "Favoritter",
    "All inboxes" : "Alle innbokser",
    "Inbox" : "Innboks",
    "Junk" : "Søppel",
    "Sent" : "Sendt",
    "Trash" : "Papirkurv",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n ny melding \nfra {from}","%n nye meldinger \nfra {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "Could not load {tag}{name}{endtag}" : "Kunne ikke laste {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Det oppstod et problem under lasting av {tag}{name}{endtag}",
    "Could not load the desired message" : "Kunne ikke laste den ønskede meldingen",
    "Could not load the message" : "Kunne ikke laste meldingen",
    "Error loading message" : "Feil ved innlasting av melding",
    "Forwarding to %s" : "Videresender til %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klikk her hvis du ikke blir videresendt automatisk innen noen få sekunder.",
    "Redirect" : "Videresend",
    "The link leads to %s" : "Denne lenken leder til %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Hvis du ikke ønsker å besøke den siden, kan du returnere til <a href=\"%s\">E-post</a>.",
    "Continue to %s" : "Fortsett til %s"
},
"nplurals=2; plural=(n != 1);");
